@@ -1,6 +1,6 @@
 ;;; consult-flymake.el --- Provides the command `consult-flymake' -*- lexical-binding: t -*-
 
-;; Copyright (C) 2021-2024 Free Software Foundation, Inc.
+;; Copyright (C) 2021-2026 Free Software Foundation, Inc.
 
 ;; This file is part of GNU Emacs.
 
@@ -98,7 +98,7 @@ buffers in the current project instead of just the current buffer."
   (consult--forbid-minibuffer)
   (consult--read
    (consult-flymake--candidates
-     (if-let ((project (and project (project-current))))
+     (if-let* ((project (and project (project-current))))
          (flymake--project-diagnostics project)
        (flymake-diagnostics)))
    :prompt "Flymake diagnostic: "
