@@ -1,6 +1,6 @@
 ;;; consult-register.el --- Consult commands for registers -*- lexical-binding: t -*-
 
-;; Copyright (C) 2021-2024 Free Software Foundation, Inc.
+;; Copyright (C) 2021-2026 Free Software Foundation, Inc.
 
 ;; This file is part of GNU Emacs.
 
@@ -84,18 +84,19 @@ Each element of the list must have the form (char . name).")
 
 (cl-defmethod consult-register--describe ((val (head file)))
   "Describe file register VAL."
-  (list (propertize (abbreviate-file-name (cdr val)) 'face 'consult-file)
+  (list (propertize (consult--fast-abbreviate-file-name (cdr val)) 'face 'consult-file)
         'consult--type ?f 'multi-category `(file . ,(cdr val))))
 
 (cl-defmethod consult-register--describe ((val (head buffer)))
   "Describe buffer register VAL."
-  (list (propertize (cdr val) 'face 'consult-buffer)
-        'consult--type ?f 'multi-category `(buffer . ,(cdr val))))
+  (let ((buf (cdr val)))
+    (list (propertize (if (bufferp buf) (buffer-name buf) buf) 'face 'consult-buffer)
+          'consult--type ?f 'multi-category `(buffer . ,buf))))
 
 (cl-defmethod consult-register--describe ((val (head file-query)))
   "Describe file-query register VAL."
   (list (format "%s at position %d"
-                (propertize (abbreviate-file-name (cadr val))
+                (propertize (consult--fast-abbreviate-file-name (cadr val))
                             'face 'consult-file)
                 (caddr val))
         'consult--type ?f 'multi-category `(file . ,(cadr val))))
@@ -116,12 +117,13 @@ Each element of the list must have the form (char . name).")
     (list (consult-register--format-value val) 'consult--type ?t)))
 
 ;;;###autoload
-(defun consult-register-window (buffer &optional show-empty)
+(defun consult-register-window (buffer &optional show-empty pred)
   "Enhanced drop-in replacement for `register-preview'.
 
 BUFFER is the window buffer.
-SHOW-EMPTY must be t if the window should be shown for an empty register list."
-  (let ((regs (consult-register--alist 'noerror))
+SHOW-EMPTY must be t if the window should be shown for an empty register list.
+Optional argument PRED specifies the types of register to show."
+  (let ((regs (consult-register--alist 'noerror pred))
         (separator
          (and (display-graphic-p)
               (propertize #(" \n" 0 1 (display (space :align-to right)))
@@ -168,24 +170,24 @@ If COMPLETION is non-nil format the register for completion."
        str))
     str))
 
-(defun consult-register--alist (&optional noerror filter)
-  "Return register list, sorted and filtered with FILTER.
+(defun consult-register--alist (&optional noerror pred)
+  "Return register list, sorted and filtered with PRED.
 Raise an error if the list is empty and NOERROR is nil."
   (or (sort (cl-loop for reg in register-alist
                      ;; Sometimes, registers are made without a `cdr' or with
                      ;; invalid markers.  Such registers don't do anything, and
                      ;; can be ignored.
-                     if (and (cdr reg)
-                             (or (not (markerp (cdr reg))) (marker-buffer (cdr reg)))
-                             (or (not filter) (funcall filter reg)))
+                     if (when-let* ((val (cdr reg)))
+                          (and (or (not (markerp val)) (marker-buffer val))
+                               (or (not pred) (funcall pred val))))
                      collect reg)
             #'car-less-than-car)
       (and (not noerror) (user-error "All registers are empty"))))
 
-(defun consult-register--candidates (&optional filter)
-  "Return formatted completion candidates, filtered with FILTER."
+(defun consult-register--candidates (&optional pred)
+  "Return formatted completion candidates, filtered with PRED."
   (mapcar (lambda (reg) (consult-register-format reg 'completion))
-          (consult-register--alist nil filter)))
+          (consult-register--alist nil pred)))
 
 ;;;###autoload
 (defun consult-register (&optional arg)
@@ -208,7 +210,7 @@ built-in register access functions.  The command supports narrowing, see
       (lambda (action cand)
         ;; Preview only markers
         (funcall preview action
-                 (when-let (reg (get-register cand))
+                 (when-let* ((reg (get-register cand)))
                    (and (markerp reg) reg)))))
     :group (consult--type-group consult-register--narrow)
     :narrow (consult--type-narrow consult-register--narrow)
@@ -248,7 +250,7 @@ This function is derived from `register-read-with-preview'."
           (lambda ()
             (unless (get-buffer-window buffer)
               (register-preview buffer 'show-empty)
-              (when-let (win (get-buffer-window buffer))
+              (when-let* ((win (get-buffer-window buffer)))
                 (with-selected-window win
                   (let ((inhibit-read-only t))
                     (goto-char (point-max))
@@ -321,7 +323,9 @@ kmacro."
     (t
      `("Store"
        (?p "point" "Point to register: " ,#'point-to-register)
-       (?f "file" "File to register: " ,(lambda (r) (set-register r `(file . ,(buffer-file-name)))))
+       ,@(when-let* ((file (or buffer-file-name default-directory)))
+          `((?f "file" "File to register: " ,(lambda (r) (set-register r `(file . ,file))))))
+       (?b "buffer" "Buffer to register: " ,(lambda (r) (set-register r `(buffer . ,(buffer-name)))))
        (?t "frameset" "Frameset to register: " ,#'frameset-to-register)
        (?w "window" "Window to register: " ,#'window-configuration-to-register)
        ,@(and last-kbd-macro `((?k "kmacro" "Kmacro to register: " ,#'kmacro-to-register))))))))
